@@ -24,7 +24,7 @@ setMethod("TSconnect",   signature(drv="PostgreSQLDriver", dbname="character"),
           stop("Database ",dbname," does not appear to be a TS database.")
 	  }
   	new("TSPostgreSQLConnection" , con, drv="PostgreSQL", dbname=dbname, 
- 	       hasVintages=dbExistsTable(con, "vintages"), 
+ 	       hasVintages=dbExistsTable(con, "vintageAlias"), 
  	       hasPanels  =dbExistsTable(con, "panels")) 
 	})
 
@@ -34,7 +34,7 @@ setMethod("TSput",   signature(x="ANY", serIDs="character", con="PostgreSQLConne
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
   TSdbi:::TSputSQL(x, serIDs, con, Table=Table, 
    TSdescription.=TSdescription., TSdoc.=TSdoc., TSlabel.=TSlabel., 
-   vintage=vintage, panel=panel,...) )
+   vintage=vintage, panel=panel) )
 
 setMethod("TSget",   signature(serIDs="character", con="PostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"), 
@@ -45,27 +45,27 @@ setMethod("TSget",   signature(serIDs="character", con="PostgreSQLConnection"),
    TSdbi:::TSgetSQL(serIDs, con, TSrepresentation=TSrepresentation,
        tf=tf, start=start, end=end,
        names=names, TSdescription=TSdescription, TSdoc=TSdoc, TSlabel=TSlabel,
-       vintage=vintage, panel=panel, ...) )
+       vintage=vintage, panel=panel) )
 
 setMethod("TSdates",    signature(serIDs="character", con="PostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-      TSdbi:::TSdatesSQL(serIDs, con, vintage=vintage, panel=panel, ...) )
+      TSdbi:::TSdatesSQL(serIDs, con, vintage=vintage, panel=panel) )
 
 
 setMethod("TSdescription",   signature(x="character", con="PostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSdescriptionSQL(x=x, con=con, ...) )
+        TSdbi:::TSdescriptionSQL(x=x, con=con) )
 
 setMethod("TSdoc",   signature(x="character", con="PostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSdocSQL(x=x, con=con, ...) )
+        TSdbi:::TSdocSQL(x=x, con=con) )
 
 setMethod("TSlabel",   signature(x="character", con="PostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSlabelSQL(x=x, con=con, ...) )
+        TSdbi:::TSlabelSQL(x=x, con=con) )
 
 setMethod("TSdelete", signature(serIDs="character", con="PostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
    vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-       TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel, ...) )
+       TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel) )
